SystemOrganization addCategory: #Stripe!
SystemOrganization addCategory: #'Stripe-Tests'!
SystemOrganization addCategory: #'Stripe-Seaside'!

TestCase subclass: #StripeTests
	instanceVariableNames: 'card amount'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe-Tests'!

StripeTests subclass: #StripeCardTests
	instanceVariableNames: 'customer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe-Tests'!

!StripeCardTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 08:33'!
testAddress1
	self assert: card address_line1 equals: '123 Main St'! !

!StripeCardTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 08:50'!
testCVC
	self assert: card cvc equals: '123'! !

!StripeCardTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 08:50'!
testMonth
	self assert: card exp_month equals: (Date today month next index ) asString! !

!StripeCardTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 08:50'!
testNumber
	self assert: card number size equals: 16.
	self assert: card number equals: '4242424242424242'.
	! !

!StripeCardTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 08:50'!
testYear
	self assert: card exp_year equals: (Date today year + 1) asString! !

!StripeCardTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 08:50'!
testZip
	self assert: card address_zip equals: '10101'! !

StripeTests subclass: #StripeChargeTests
	instanceVariableNames: 'customer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe-Tests'!

!StripeChargeTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 11:24'!
testChargeCard
	| charge |
	charge := StripeCharge newChargeFor: amount toCard: card.
	self assert: charge values notEmpty.
	self assert: (charge values at: 'amount') equals: 100.
	self assert: (charge values at: 'livemode') equals: false.
	self assert: (charge values at: 'object') equals: 'charge'.
	self assert: (charge values at: 'paid') equals: true.
	self assert: (charge values at: 'refunded') equals: false.
	self assert: (charge values at: 'card') className equals: 'StripeCard'.
	self assert: (StripeCharge instances includes: charge).
	StripeCharge instances remove: charge ifAbsent: [  ]! !

!StripeChargeTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 10:13'!
testRefundCharge
	|charge refundedCharge |
	charge:=StripeCharge newChargeFor: amount toCard: card.
	self assert:( charge values at:'amount' )equals:100.
	refundedCharge:=charge refund: 51.
	self assert:(refundedCharge values at: 'amount_refunded') equals:51.
	self assert:(charge id = refundedCharge id ).
	
	StripeCharge instances remove: charge ifAbsent:[].
	! !

!StripeChargeTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 10:52'!
testRetrieveCharge
	|charge retrievedCharge chargeId |
	charge:=StripeCharge newChargeFor: amount toCard: card.
	chargeId:=charge id.
	self assert:( charge values at:'amount' )equals:100.
	retrievedCharge:=charge retrieveFromStripe.

	self assert:(chargeId = retrievedCharge id ).

	StripeCharge instances remove: charge ifAbsent:[].
	! !

!StripeChargeTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 11:21'!
testRetrieveRecentCharges
	|charges retrievedCharge chargeId |
	charges:=StripeCharge retrieveLast: 3 starting: 0.
	self assert: charges size equals: 3.
	! !

StripeTests subclass: #StripeCouponTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe-Tests'!

!StripeCouponTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 12:03'!
testCreateCoupon
	|dict coupon|
	dict:=Dictionary new.
	dict at:'id' put: '10_pct'.
	dict at:'percent_off' put: '10'.
	dict at:'duration' put: 'repeating'.
	dict at: 'duration_in_months' put: '3'.
	dict at: 'max_redemptions' put: '10'.
	dict at:'redeem_by' put: ((DateAndTime today + 60 days) asUnixTime ) asString.
	coupon:=StripeCoupon newFrom: dict.
	self assert: coupon id equals: '10_pct'.
	coupon deleteFromStripe.! !

!StripeCouponTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 12:49'!
testDeleteCoupon
	|dict coupon newCoupon id |

	dict:=Dictionary new.
	dict at:'id' put:  '10_pct'.
	dict at:'percent_off' put: '10'.
	dict at:'duration' put: 'repeating'.
	dict at: 'duration_in_months' put: '3'.
	dict at: 'max_redemptions' put: '10'.
	dict at:'redeem_by' put: ((DateAndTime today + 60 days) asUnixTime ) asString.
	coupon:=StripeCoupon newFrom: dict.
	self assert: coupon id equals: '10_pct'.
	coupon deleteFromStripe.
"	self should: (coupon retrieveFromStripe ) raise: StripeError. "
	! !

!StripeCouponTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 11:57'!
testRetrieveCoupon
	|dict coupon newCoupon |
	dict:=Dictionary new.
	dict at:'id' put: '10_pct'.
	dict at:'percent_off' put: '10'.
	dict at:'duration' put: 'repeating'.
	dict at: 'duration_in_months' put: '3'.
	dict at: 'max_redemptions' put: '10'.
	dict at:'redeem_by' put: ((DateAndTime today + 60 days) asUnixTime ) asString.
	coupon:=StripeCoupon newFrom: dict.
	self assert: coupon id equals: '10_pct'.
	newCoupon:=coupon retrieveFromStripe.
	self assert: newCoupon id equals: '10_pct'.! !

StripeTests subclass: #StripeCustomerTests
	instanceVariableNames: 'coupon plan'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe-Tests'!

!StripeCustomerTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 13:03'!
setUp
	|dict|
	super setUp.
	dict:=Dictionary new.
	dict at:'id' put: '10_pct'.
	dict at:'percent_off' put: '10'.
	dict at:'duration' put: 'repeating'.
	dict at: 'duration_in_months' put: '3'.
	dict at: 'max_redemptions' put: '10'.
	dict at:'redeem_by' put: ((DateAndTime today + 60 days) asUnixTime ) asString.
	coupon:=StripeCoupon newFrom: dict.
		dict:=Dictionary new.
	dict at:'id' put: 'small'.
	dict at:'amount' put: '1000'.
	dict at:'currency' put: 'usd'.
	dict at: 'interval' put: 'month'.
	dict at: 'name' put: 'Small Plan'.
	dict at:'trial_period_days' put: ((DateAndTime today + 30 days) asUnixTime ) asString.
	plan:=StripePlan newFrom: dict.! !

!StripeCustomerTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 12:50'!
tearDown
	coupon deleteFromStripe.
	plan deleteFromStripe .! !

!StripeCustomerTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 15:16'!
testCancelCustomerSubscription
	|cust dict|

	dict:=Dictionary new.
	dict at: 'email' put:'me@example.com'. 
	dict at: 'coupon' put:'10_pct'. 
	dict at: 'plan' put:'small'. 
	dict at: 'description' put:'my name'. 
	dict at: 'trial_end' put:( (DateAndTime today + 30 days) asUnixTime) asString.
	cust:=StripeCustomer newFromCard: card with: dict.
	self assert: cust email equals: 'me@example.com'.
	
	self assert: cust cancelSubscriptionNow.
		"StripeCustomer instances remove: cust ifAbsent:[] ."

	! !

!StripeCustomerTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 13:55'!
testCreateCustomer
	|cust dict|
	cust:=StripeCustomer newFromCard: card.
	
	
	StripeCustomer instances remove: cust ifAbsent:[] .
	dict:=Dictionary new.
	dict at: 'email' put:'me@example.com'. 
	dict at: 'coupon' put:'10_pct'. 
	dict at: 'plan' put:'small'. 
	dict at: 'description' put:'my name'. 
	dict at: 'trial_end' put:( (DateAndTime today + 30 days) asUnixTime) asString.
	cust:=StripeCustomer newFromCard: card with: dict.
	self assert: cust email equals: 'me@example.com'.
	self assert: cust coupon id equals: '10_pct'.
	self assert: cust plan id equals: 'small'.
	self assert: cust description equals: 'my name'.
	self assert: cust trial_end equals: (DateAndTime today + 30 days) asUnixTime.
		"StripeCustomer instances remove: cust ifAbsent:[] ."

	! !

!StripeCustomerTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 14:13'!
testUpdateCustomer
	|cust dict|

	dict:=Dictionary new.
	dict at: 'email' put:'me@example.com'. 
	dict at: 'coupon' put:'10_pct'. 
	dict at: 'plan' put:'small'. 
	dict at: 'description' put:'my name'. 
	dict at: 'trial_end' put:( (DateAndTime today + 30 days) asUnixTime) asString.
	cust:=StripeCustomer newFromCard: card with: dict.
	self assert: cust email equals: 'me@example.com'.
	dict:=Dictionary new.
	dict at: 'email' put:'you@example.com'.
	cust:=cust updateWith: dict.
	self assert: cust email equals: 'you@example.com'
		"StripeCustomer instances remove: cust ifAbsent:[] ."

	! !

StripeTests subclass: #StripeInvoiceItemTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe-Tests'!

!StripeInvoiceItemTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 15:34'!
testCreateAndDelete
	|cust item|
	cust:=StripeCustomer newFromCard: card.
	item :=StripeInvoiceItem charge: 10 to: cust.
	self assert: item className equals:'StripeInvoiceItem'.
	self assert:	item deleteFromStripe.! !

!StripeInvoiceItemTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 15:43'!
testUpdate
	|cust item dict|
	cust:=StripeCustomer newFromCard: card.
	item :=StripeInvoiceItem charge: 10 to: cust.
	self assert: item className equals:'StripeInvoiceItem'.
	self assert: item amount equals:10.
	item updateAmountTo: 25.
	self assert: item amount equals:25! !

StripeTests subclass: #StripeInvoiceTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe-Tests'!

!StripeInvoiceTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 16:42'!
testGetUpcomingInvoice
	| cust invoice |
	cust := StripeCustomer newFromCard: card.
	invoice := cust getUpcomingInvoice.
	self assert: invoice className equals: 'StripeInvoice'! !

StripeTests subclass: #StripePlanTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe-Tests'!

!StripePlanTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 12:54'!
testCreatePlan
	|dict plan|
	dict:=Dictionary new.
	dict at:'id' put: 'small'.
	dict at:'amount' put: '1000'.
	dict at:'currency' put: 'usd'.
	dict at: 'interval' put: 'month'.
	dict at: 'name' put: 'Small Plan'.
	dict at:'trial_period_days' put: ((DateAndTime today + 30 days) asUnixTime ) asString.
	plan:=StripePlan newFrom: dict.
	self assert: plan id equals: 'small'.
	plan deleteFromStripe.! !

StripeTests subclass: #StripeSystemTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe-Tests'!

!StripeSystemTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 09:03'!
testObjectsToIds
	|ids|
	ids:=StripeSystem objectsToIds: card values.
	self assert: ids notEmpty.! !

!StripeTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 08:50'!
setUp
	card:=StripeCard new number:'4242424242424242';
					exp_month: (Date today month next index) asString ;
					exp_year:( Date today year + 1) asString;
					cvc: '123';
					address_line1: '123 Main St';
					address_zip:'10101'.
	amount:='100'.! !

StripeTests subclass: #StripeTokenTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe-Tests'!

!StripeTokenTests methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 14:56'!
testCreateToken
	|token|
	token:=StripeToken newFrom: card for: '200'.
	self assert:token className equals:'StripeToken'
! !

WAComponent subclass: #StripeCreditCardForm
	instanceVariableNames: 'token'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe-Seaside'!

!StripeCreditCardForm commentStamp: 'PaulDeBruicker 10/21/2011 14:45' prior: 0!
You need to put your publishable key in the YOUR_PUBLISHABLE_KEY spot in the renderContentOn: method!

!StripeCreditCardForm classSide methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/21/2011 15:17'!
canBeRoot
	^ true! !

!StripeCreditCardForm classSide methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/21/2011 15:19'!
initialize 
"
StripeCreditCardForm initialize
"
| app |
	app := WAAdmin register: self asApplicationAt: 'stripe'.
	(app filters detect: #isExceptionFilter) configuration at: #exceptionHandler put: WADebugErrorHandler.

	! !

!StripeCreditCardForm methodsFor: 'javascript' stamp: 'PaulDeBruicker 10/24/2011 09:11'!
addTokenToForm

	^     'var pmtForm = $("#payment-form");
        var token = response["id"];
        $("#' , self tokenDiv ,'").val(token);
        pmtForm.get(0).submit();}'! !

!StripeCreditCardForm methodsFor: 'divIDs' stamp: 'PaulDeBruicker 10/21/2011 16:07'!
addressOneDiv
	^'addr-one'! !

!StripeCreditCardForm methodsFor: 'charge-details' stamp: 'PaulDeBruicker 10/21/2011 17:10'!
amount
	"amount in cents.  so $1.00 = 100"
		^100! !

!StripeCreditCardForm methodsFor: 'divIDs' stamp: 'PaulDeBruicker 10/21/2011 16:06'!
cardNumberDiv
	^'card-number'! !

!StripeCreditCardForm methodsFor: 'rendering' stamp: 'PaulDeBruicker 10/25/2011 16:46'!
chargeCustomerFor: aStripeToken
	|cust charge|
	cust:=StripeCustomer newFromToken: aStripeToken. 
	charge:=StripeCharge newChargeFor: self amount toCustomer: cust
! !

!StripeCreditCardForm methodsFor: 'javascript' stamp: 'PaulDeBruicker 10/24/2011 10:02'!
createStripeTokenForSimpleForm
	^((self disableSubmitButton , self setAmount , self createToken , self stopReturn) asFunction: #('event') named: 'createStripeToken')! !

!StripeCreditCardForm methodsFor: 'javascript' stamp: 'PaulDeBruicker 10/24/2011 08:37'!
createToken
	^(JSStream on: 'Stripe.createToken(' , self createTokenData  , ', amount , ' , self responseHandlerFunctionName , ')').! !

!StripeCreditCardForm methodsFor: 'javascript' stamp: 'PaulDeBruicker 10/24/2011 08:36'!
createTokenData
	^ '{number : $("#' , self cardNumberDiv , '").val(),cvc:$("#' , self cvcDiv , '").val() , exp_month : $("#'
		, self monthDiv , '").val(), exp_year : $("#' , self yearDiv , '").val(), address_line1 : $("#' , self addressOneDiv
		, '").val(), address_zip : $("#' , self zipDiv , '").val()}'! !

!StripeCreditCardForm methodsFor: 'divIDs' stamp: 'PaulDeBruicker 10/21/2011 16:06'!
cvcDiv
	^'card-cvc'! !

!StripeCreditCardForm methodsFor: 'javascript' stamp: 'PaulDeBruicker 10/24/2011 10:32'!
disableSubmitButton
	^JSStream on:'$("#', self formDiv ,' .submit").attr("disabled","disabled")'! !

!StripeCreditCardForm methodsFor: 'divIDs' stamp: 'PaulDeBruicker 10/24/2011 10:46'!
errorDiv 
	^'card-error'! !

!StripeCreditCardForm methodsFor: 'javascript' stamp: 'PaulDeBruicker 10/24/2011 11:23'!
errorNotification
	^' 
	if (response.error) {
	$("#payment-form .submit").removeAttr("disabled");
	if ((response.param = "exp_year")||(response.param ="exp_month")) {
	 $("#', self errorDiv , '").html("The expiration date is incorrect");
	} else {
        $("#', self errorDiv , '").html(response.error.message);
	}
    } else {'! !

!StripeCreditCardForm methodsFor: 'divIDs' stamp: 'PaulDeBruicker 10/24/2011 10:30'!
formDiv
	^'payment-form'! !

!StripeCreditCardForm methodsFor: 'divIDs' stamp: 'PaulDeBruicker 10/21/2011 16:06'!
monthDiv
	^'card-month-expiry'! !

!StripeCreditCardForm methodsFor: 'rendering' stamp: 'PaulDeBruicker 10/21/2011 16:16'!
renderAddressRow: html
	html div
		class: 'form-row';
		with: [ 
					html label
						for: self addressOneDiv;
						with: 'Street Address:'.
					html break.
					html textInput
						name: nil;
						id: self addressOneDiv;
						size: 20.
					html break.
					html label
						for: self addressOneDiv;
						with: 'Zip Code:'.
					html break.
					html textInput
						name: nil;
						id: self zipDiv;
						size: 6 ]! !

!StripeCreditCardForm methodsFor: 'rendering' stamp: 'PaulDeBruicker 10/24/2011 08:24'!
renderCVCRow: html
	html div
		class: 'form-row';
		with: [ 
					html label
						for: self cvcDiv;
						with: 'CVC:'.
						html break.
					html textInput
						name: nil;
						id: self cvcDiv;
						size: 4;
						noAutocomplete  ]! !

!StripeCreditCardForm methodsFor: 'rendering' stamp: 'PaulDeBruicker 10/24/2011 08:24'!
renderCardNumberRow: html
	html div
		class: 'form-row';
		with: [ 
					html label
						for: self cardNumberDiv;
						with: 'Card Number:'.
						html break.
					html textInput
						name: nil;
						id: self cardNumberDiv;
						size: 20;
						noAutocomplete  ]! !

!StripeCreditCardForm methodsFor: 'rendering' stamp: 'PaulDeBruicker 10/24/2011 10:30'!
renderContentOn: html
	html script: self setPublishableKey.
	html form
		method: 'post';
		id: self formDiv ;
		with: [ 		self renderValidationErrorOn: html.
					self renderCardNumberRow: html.
					self renderCVCRow: html.
					self renderExpirationRow: html.
					self renderAddressRow: html.
					self renderTokenHiddenInput:html.
					html submitButton
						onClick: (html jQuery script: [:s | s<<(self createStripeTokenForSimpleForm).
														s<< (JSStream on: 'createStripeToken()')]);
						with: 'Submit Payment' ].
	self renderStripeResponseHandler:html! !

!StripeCreditCardForm methodsFor: 'rendering' stamp: 'PaulDeBruicker 10/21/2011 16:15'!
renderExpirationRow: html
	html div
		class: 'form-row';
		with: [ 
					html label
						for: self monthDiv ;
						with: 'Expiration (MM/YYYY):'.
						html break.
					html textInput
						name: nil;
						id: self monthDiv ;
						size: 2.
					html span: ' / '.
					html textInput
						name: nil;
						size: 4;
						id: self yearDiv ]! !

!StripeCreditCardForm methodsFor: 'rendering' stamp: 'PaulDeBruicker 10/24/2011 09:28'!
renderStripeResponseHandler:  html
	
	
	html script: ((JSStream on: self stripeResponseHandler) asFunction: #('status' 'response') named: self responseHandlerFunctionName  )! !

!StripeCreditCardForm methodsFor: 'rendering' stamp: 'PaulDeBruicker 10/25/2011 16:45'!
renderTokenHiddenInput: html
	html hiddenInput id:self tokenDiv ; callback:[:val | val=''  ifFalse:[self chargeCustomerFor: val]]! !

!StripeCreditCardForm methodsFor: 'rendering' stamp: 'PaulDeBruicker 10/24/2011 09:15'!
renderValidationErrorOn: html

	html div id: self errorDiv; style:'color:#FF0000'! !

!StripeCreditCardForm methodsFor: 'javascript' stamp: 'PaulDeBruicker 10/24/2011 08:37'!
responseHandlerFunctionName
	^'stripeResponseHandler'! !

!StripeCreditCardForm methodsFor: 'javascript' stamp: 'PaulDeBruicker 10/21/2011 17:11'!
setAmount
	^JSStream on: 'var amount = ' , self amount greaseString ! !

!StripeCreditCardForm methodsFor: 'javascript' stamp: 'PaulDeBruicker 10/24/2011 18:14'!
setPublishableKey 
	^(JSStream on: 'Stripe.setPublishableKey("' , StripeObject publishableApiKey  , '")').! !

!StripeCreditCardForm methodsFor: 'javascript' stamp: 'PaulDeBruicker 10/24/2011 09:44'!
stopReturn
	^JSStream on:'return false'! !

!StripeCreditCardForm methodsFor: 'javascript' stamp: 'PaulDeBruicker 10/24/2011 10:33'!
stripeResponseHandler 
	^ self errorNotification , self addTokenToForm ! !

!StripeCreditCardForm methodsFor: 'keys' stamp: 'PaulDeBruicker 10/21/2011 15:19'!
stripeTestAPIKey 
	^'pk_WLpX9yZ4Rq6C3qFq0tlsXJnnE3GQ8'! !

!StripeCreditCardForm methodsFor: 'divIDs' stamp: 'PaulDeBruicker 10/24/2011 08:46'!
tokenDiv
	^'cc-token'! !

!StripeCreditCardForm methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/21/2011 15:21'!
updateRoot: htmlRoot
	htmlRoot javascript url:'http://code.jquery.com/jquery-1.6.4.min.js'.
	htmlRoot javascript url: 'https://js.stripe.com/v1/'! !

!StripeCreditCardForm methodsFor: 'divIDs' stamp: 'PaulDeBruicker 10/21/2011 16:07'!
yearDiv
	^'card-year-expiry'! !

!StripeCreditCardForm methodsFor: 'divIDs' stamp: 'PaulDeBruicker 10/21/2011 16:07'!
zipDiv
	^'zipcode'! !

Object subclass: #StripeObject
	instanceVariableNames: 'id created description apiKey values unsavedValues transientValues'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe'!

StripeObject subclass: #StripeCard
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe'!

!StripeCard methodsFor: 'accessing' stamp: 'PaulDeBruicker 10/25/2011 08:56'!
address_country
	^ values at: 'address_country'! !

!StripeCard methodsFor: 'accessing' stamp: 'PaulDeBruicker 10/25/2011 08:56'!
address_country: anObject
	values at: 'address_country' put: anObject! !

!StripeCard methodsFor: 'accessing' stamp: 'PaulDeBruicker 10/25/2011 08:58'!
address_line1
	^ values at: 'address_line1'! !

!StripeCard methodsFor: 'accessing' stamp: 'PaulDeBruicker 10/25/2011 08:57'!
address_line1: anObject
	values at: 'address_line1' put: anObject! !

!StripeCard methodsFor: 'accessing' stamp: 'PaulDeBruicker 10/25/2011 08:58'!
address_line2
	^ values at: 'address_line2'! !

!StripeCard methodsFor: 'accessing' stamp: 'PaulDeBruicker 10/25/2011 08:57'!
address_line2: anObject
	values at: 'address_line2' put: anObject! !

!StripeCard methodsFor: 'accessing' stamp: 'PaulDeBruicker 10/25/2011 08:58'!
address_state
	^ values at: 'address_state'! !

!StripeCard methodsFor: 'accessing' stamp: 'PaulDeBruicker 10/25/2011 08:57'!
address_state: anObject
	values at: 'address_state' put: anObject! !

!StripeCard methodsFor: 'accessing' stamp: 'PaulDeBruicker 10/25/2011 08:59'!
address_zip
	^ values at: 'address_zip'! !

!StripeCard methodsFor: 'accessing' stamp: 'PaulDeBruicker 10/25/2011 08:57'!
address_zip: anObject
	values at: 'address_zip' put: anObject! !

!StripeCard methodsFor: 'accessing' stamp: 'PaulDeBruicker 10/25/2011 14:51'!
createToken
	! !

!StripeCard methodsFor: 'accessing' stamp: 'PaulDeBruicker 10/25/2011 08:59'!
cvc
	^ values at: 'cvc'! !

!StripeCard methodsFor: 'accessing' stamp: 'PaulDeBruicker 10/25/2011 08:57'!
cvc: anObject
	values at: 'cvc' put: anObject! !

!StripeCard methodsFor: 'accessing' stamp: 'PaulDeBruicker 10/25/2011 08:59'!
exp_month
	^ values at: 'exp_month'! !

!StripeCard methodsFor: 'accessing' stamp: 'PaulDeBruicker 10/25/2011 08:57'!
exp_month: anObject
	values at: 'exp_month' put: anObject! !

!StripeCard methodsFor: 'accessing' stamp: 'PaulDeBruicker 10/25/2011 08:59'!
exp_year
	^ values at: 'exp_year'! !

!StripeCard methodsFor: 'accessing' stamp: 'PaulDeBruicker 10/25/2011 08:58'!
exp_year: anObject
	values at: 'exp_year' put: anObject! !

!StripeCard methodsFor: 'accessing' stamp: 'PaulDeBruicker 10/25/2011 08:59'!
name
	^ values at: 'name'! !

!StripeCard methodsFor: 'accessing' stamp: 'PaulDeBruicker 10/25/2011 08:58'!
name: anObject
	values at: 'name' put: anObject! !

!StripeCard methodsFor: 'accessing' stamp: 'PaulDeBruicker 10/25/2011 08:59'!
number
	^ values at: 'number'! !

!StripeCard methodsFor: 'accessing' stamp: 'PaulDeBruicker 10/25/2011 08:58'!
number: anObject
	values at: 'number' put: anObject! !

StripeObject subclass: #StripeCharge
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe'!

!StripeCharge class methodsFor: 'instance creation' stamp: 'PaulDeBruicker 10/25/2011 08:25'!
newChargeFor: anAmount toCard: aCard 
	^self new charge: anAmount to: aCard with: ''! !

!StripeCharge class methodsFor: 'instance creation' stamp: 'PaulDeBruicker 10/25/2011 08:25'!
newChargeFor: anAmount toCard: aCard withDescription: aDescription
	^self new charge: anAmount to: aCard with: aDescription! !

!StripeCharge class methodsFor: 'instance creation' stamp: 'PaulDeBruicker 10/25/2011 08:25'!
newChargeFor: anAmount toCustomer: aCustomer
	^self new charge: anAmount toCustomer: aCustomer with: ''! !

!StripeCharge class methodsFor: 'instance creation' stamp: 'PaulDeBruicker 10/25/2011 08:25'!
newChargeFor: anAmount toCustomer: aCustomer with: aDescription
	^self new charge: anAmount toCustomer: aCustomer with: aDescription! !

!StripeCharge methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 16:46'!
charge: anAmount to: aCard with: aDescription

	|dict charge|
	dict:=Dictionary new.
	dict at: 'amount' put: anAmount asString. "amount must be in pennies e.g. 99 equals $0.99"
	dict at: 'description' put:( description:=aDescription).
	dict at: 'currency' put: 'usd'. "they only support USD right now`"
	dict at: 'card[number]' put: aCard number.
	dict at: 'card[cvc]' put: aCard cvc.
	dict at: 'card[exp_month]' put: aCard exp_month.
	dict at: 'card[exp_year]' put: aCard exp_year.
	aCard address_line1 notNil ifTrue:[
	dict at: 'card[address_line1]' put: aCard address_line1].
	aCard address_zip notNil ifTrue:[
	dict at: 'card[address_zip]' put: aCard address_zip].
	
	self createWith: dict.

	! !

!StripeCharge methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 08:26'!
charge: anAmount toCustomer: aCustomer with: aDescription

	|dict charge|
	dict:=Dictionary new.
	dict at: 'amount' put: anAmount. "amount must be in pennies e.g. 99 equals $0.99"
	dict at: 'customer' put: aCustomer id.
	dict at: 'description' put:( description:=aDescription).
	dict at: 'currency' put: 'usd'. "they only support USD right now`"
	self createWith: dict.

	! !

!StripeCharge methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/24/2011 17:56'!
object
	^'charge'! !

!StripeCharge methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 10:06'!
refund: anAmount
	|response client parsed dict |
	client:= (ZnNeoClient new) logToTranscript.
	client username: self class secretApiKey password:''.
	"client formAt:'id' put: self id."
	client formAt:'amount' put: anAmount asString.
	response:=(client url: self  refundUrl; post) .
	parsed:=JSJsonParser parse: response asString readStream. 
	
	self refreshFrom: parsed with: self class secretApiKey . 
	
	
	! !

!StripeCharge methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 10:02'!
refundUrl 
	^self class url , '/' , self id , '/refund'! !

StripeObject subclass: #StripeCoupon
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe'!

!StripeCoupon class methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 12:39'!
newFrom: aDictionary
"see https://stripe.com/docs/api?lang=curl#create_coupon 

you can't create more than one of the same coupon, so we check to see if the one you want to make exists and if not create it"
|existingCoupon | 
	existingCoupon:=self retrieveWithId: (aDictionary at: 'id').
	^existingCoupon isNil ifTrue:[self new createWith: aDictionary] ifFalse:[existingCoupon]! !

!StripeCoupon class methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 12:46'!
retrieveWithId: anId
	| response client parsed |
	client := ZnNeoClient new logToTranscript.
	client username: self secretApiKey password: ''.
	client url: self url , '/' , anId.
	response := client get.
	parsed := JSJsonParser parse: response asString readStream.
	parsed
		at: 'error'
		ifPresent: [ :v | ^nil ]
		ifAbsent: [ ^ StripeSystem convert: parsed toStripeObjectUsing: self secretApiKey ]! !

!StripeCoupon methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/24/2011 17:57'!
object
	^'coupon'! !

StripeObject subclass: #StripeCustomer
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe'!

!StripeCustomer class methodsFor: 'instance creation' stamp: 'PaulDeBruicker 10/25/2011 11:34'!
newFromCard: aCard

	^self new createFromCard: aCard with: Dictionary new.! !

!StripeCustomer class methodsFor: 'instance creation' stamp: 'PaulDeBruicker 10/25/2011 11:34'!
newFromCard: aCard with: optionalDictionary

	^self new createFromCard: aCard with: optionalDictionary
! !

!StripeCustomer class methodsFor: 'instance creation' stamp: 'PaulDeBruicker 10/25/2011 11:35'!
newFromToken: aToken

	^self new createFromToken: aToken with: Dictionary new.! !

!StripeCustomer class methodsFor: 'instance creation' stamp: 'PaulDeBruicker 10/25/2011 11:35'!
newFromToken: aToken with: optionalDictionary

	^self new createFromToken: aToken with: optionalDictionary ! !

!StripeCustomer methodsFor: 'subscriptions' stamp: 'PaulDeBruicker 10/25/2011 15:11'!
cancelSubscriptionAtEndOfCurrentPeriod
	|response client parsed |
	client:= (ZnNeoClient new) logToTranscript.
	client username: self class secretApiKey password:''.
	client queryAt:'at_period_end' put: true.
	response:=(client url: self  subscriptionUrl; delete) .
	parsed:=JSJsonParser parse: response asString readStream. 

	^parsed at:'status' = 'cancelled'! !

!StripeCustomer methodsFor: 'subscriptions' stamp: 'PaulDeBruicker 10/25/2011 15:20'!
cancelSubscriptionNow
	|response client parsed |
	client:= (ZnNeoClient new) logToTranscript.
	client username: self class secretApiKey password:''.
	response:=(client url: self  subscriptionUrl; delete) .
	parsed:=JSJsonParser parse: response asString readStream. 

	^(parsed at:'ended_at') notNil! !

!StripeCustomer methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 13:49'!
coupon
	^(values at:'discount') coupon! !

!StripeCustomer methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 11:33'!
createFromCard: aCard with: optionalDictionary
	|dict|
	dict:=Dictionary new.

	optionalDictionary keysAndValuesDo: [:name :option | dict at: name put: option].
	dict at: 'card[number]' put: aCard number.
	dict at: 'card[cvc]' put: aCard cvc.
	dict at: 'card[exp_month]' put: aCard exp_month.
	dict at: 'card[exp_year]' put: aCard exp_year.
	aCard address_line1 notNil ifTrue:[
	dict at: 'card[address_line1]' put: aCard address_line1].
	aCard address_zip notNil ifTrue:[
	dict at: 'card[address_zip]' put: aCard address_zip].
	^self createWith: dict! !

!StripeCustomer methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 11:34'!
createFromToken: aToken with: optionalDictionary
	|dict|
	dict:=Dictionary new.

	optionalDictionary keysAndValuesDo: [:name :option | dict at: name put: option].
	dict at: 'card' put: aToken.
	
	
	^self createWith: dict! !

!StripeCustomer methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 11:44'!
description 
	^values at:'description'
	! !

!StripeCustomer methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 11:44'!
email
	^values at: 'email'! !

!StripeCustomer methodsFor: 'invoices' stamp: 'PaulDeBruicker 10/25/2011 16:12'!
getUpcomingInvoice

	|response client parsed |
	client:= (ZnNeoClient new) logToTranscript.
	client username: self class secretApiKey password:''.
	client url: self  invoiceUrl.
	client queryAt: 'customer' put:self id. 
	response:= client get .
	parsed:=JSJsonParser parse: response asString readStream. 
	parsed at:'error' ifPresent:[:v| StripeError new signal:((parsed at:'error') at:'message')]ifAbsent:[
	^StripeSystem convert: parsed toStripeObjectUsing: self class secretApiKey]! !

!StripeCustomer methodsFor: 'invoices' stamp: 'PaulDeBruicker 10/25/2011 16:04'!
invoiceUrl
	^StripeInvoice url ,'/upcoming'! !

!StripeCustomer methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/24/2011 17:57'!
object
	^'customer'! !

!StripeCustomer methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 15:13'!
plan
	^self subscription plan! !

!StripeCustomer methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 15:13'!
subscription
	^(values at: 'subscription') ! !

!StripeCustomer methodsFor: 'subscriptions' stamp: 'PaulDeBruicker 10/25/2011 15:07'!
subscriptionUrl
	^self updateUrl , '/subscription'  ! !

!StripeCustomer methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 15:13'!
trial_end 
	^self subscription trial_end! !

!StripeCustomer methodsFor: 'subscriptions' stamp: 'PaulDeBruicker 10/25/2011 15:07'!
updateSubscriptionTo: aDictionary

	|response client parsed |
	client:= (ZnNeoClient new) logToTranscript.
	client username: self class secretApiKey password:''.
	client formAddAll:  aDictionary.
	response:=(client url: self  subscriptionUrl; post) .
	parsed:=JSJsonParser parse: response asString readStream. 
	self refreshFrom: parsed with: self class secretApiKey partially: true ! !

!StripeCustomer methodsFor: 'subscriptions' stamp: 'PaulDeBruicker 10/25/2011 15:03'!
updateSubscriptionToPlanNamed: aName

	|dict|
	dict:=Dictionary new.
	dict at:'plan' put: aName.
	self updateSubscriptionTo:dict ! !

StripeObject subclass: #StripeDiscount
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe'!

!StripeDiscount methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 13:50'!
coupon
	^values at: 'coupon'! !

StripeObject subclass: #StripeInvoice
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe'!

!StripeInvoice class methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 16:05'!
retrieveWithId: anId
	| response client parsed |
	client := ZnNeoClient new logToTranscript.
	client username: self secretApiKey password: ''.
	client url: self url , '/' , anId.
	response := client get.
	parsed := JSJsonParser parse: response asString readStream.
	parsed
		at: 'error'
		ifPresent: [ :v | ^nil ]
		ifAbsent: [ ^ StripeSystem convert: parsed toStripeObjectUsing: self secretApiKey ]! !

!StripeInvoice methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/24/2011 17:57'!
object
	^'invoice'! !

StripeObject subclass: #StripeInvoiceItem
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe'!

!StripeInvoiceItem class methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 15:42'!
charge:anAmount to: aCustomer
	|dict|
	dict:=Dictionary new.
	dict at: 'customer' put: aCustomer id.
	dict at:'amount' put: anAmount asString.
	dict at:'currency' put: 'usd'.
	^self newFrom: dict! !

!StripeInvoiceItem class methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 15:22'!
newFrom: aDictionary
"see https://stripe.com/docs/api?lang=curl#create_invoiceitem"
^self new createWith: aDictionary! !

!StripeInvoiceItem methodsFor: 'accessing' stamp: 'PaulDeBruicker 10/25/2011 15:43'!
amount
	^(values at: 'amount')! !

!StripeInvoiceItem methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/24/2011 17:57'!
object
	^'invoiceitem'! !

!StripeInvoiceItem methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 15:41'!
updateAmountTo: anAmount
	|dict|
	dict:=Dictionary new.
	dict at: 'amount' put: anAmount asString.
	dict at: 'currency' put: 'usd'.
	^self updateWith: dict
	! !

!StripeObject class methodsFor: 'storing' stamp: 'PaulDeBruicker 10/24/2011 18:00'!
instances
	^ StripeSystem instancesOf: self! !

!StripeObject class methodsFor: 'instance creation' stamp: 'PaulDeBruicker 10/24/2011 15:23'!
newFrom: aResponse using: anApiKey
	^ self new from: aResponse using: anApiKey! !

!StripeObject class methodsFor: 'keys' stamp: 'PaulDeBruicker 10/25/2011 16:53'!
publishableApiKey
	^ self testPublishableAPIKey! !

!StripeObject class methodsFor: 'storing' stamp: 'PaulDeBruicker 10/25/2011 10:48'!
removeTestObjects
	self instances removeAllSuchThat:[:each | (each values at: 'livemode') = false]! !

!StripeObject class methodsFor: 'storing' stamp: 'PaulDeBruicker 10/25/2011 14:02'!
removeTestObjectsFromStripe
	|objs|
	objs:= self retrieveLast: 100 starting:0.
	objs do:[:each | each deleteFromStripe ].! !

!StripeObject class methodsFor: 'retrieve' stamp: 'PaulDeBruicker 10/25/2011 11:12'!
retrieveLast: aCount starting: anOffset 
	^self retrieveLast: aCount starting: anOffset for: ''! !

!StripeObject class methodsFor: 'retrieve' stamp: 'PaulDeBruicker 10/25/2011 11:20'!
retrieveLast: aCount starting: anOffset for: aCustomer
	|response client parsed |
	client:= (ZnNeoClient new) logToTranscript.
	client username: self secretApiKey password:''.
	client url: self  url.
	client queryAt: 'count' put: aCount asString.
	client queryAt: 'offset' put: anOffset asString.
	aCustomer isEmptyOrNil ifFalse:[client queryAt: 'customer' put: aCustomer ]. 
	response:=(client  get) .
	parsed:=JSJsonParser parse: response asString readStream.
	^StripeSystem convert: (parsed at: 'data') toStripeObjectUsing: self secretApiKey  ! !

!StripeObject class methodsFor: 'keys' stamp: 'PaulDeBruicker 10/24/2011 18:14'!
secretApiKey
	^self testSecretApiKey ! !

!StripeObject class methodsFor: 'urls' stamp: 'PaulDeBruicker 10/24/2011 16:58'!
stripeBaseUrl
	^'https://api.stripe.com/v1'
	"',self apiKey ,'@"! !

!StripeObject class methodsFor: 'keys' stamp: 'PaulDeBruicker 10/25/2011 16:55'!
testPublishableAPIKey 
	^'Your Publishable Key'! !

!StripeObject class methodsFor: 'keys' stamp: 'PaulDeBruicker 10/25/2011 16:55'!
testSecretApiKey
	^'Your Secret Key'! !

!StripeObject class methodsFor: 'urls' stamp: 'PaulDeBruicker 10/24/2011 18:27'!
url
	|className|
	className:=self name.
	^ self stripeBaseUrl ,'/', (className copyFrom: 7 to: className size) asLowercase , 's'! !

!StripeObject methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/24/2011 16:08'!
asJson
	^values asJson! !

!StripeObject methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 10:10'!
createWith: aDictionary
	|response client parsed |
	client:= (ZnNeoClient new) logToTranscript.
	client username: self class secretApiKey password:''.
	client formAddAll: aDictionary.
	response:=(client url: self  class url; post) .
	parsed:=JSJsonParser parse: response asString readStream. 
	
	self refreshFrom: parsed with: self class secretApiKey . 

	self class instances add: self.
	
	! !

!StripeObject methodsFor: 'deleting' stamp: 'PaulDeBruicker 10/25/2011 12:09'!
deleteFromStripe
	|response client parsed |
	client:= (ZnNeoClient new) logToTranscript.
	client username: self class secretApiKey password:''.
	response:=(client url: self  deleteUrl; delete) .
	parsed:=JSJsonParser parse: response asString readStream. 

	^parsed at:'deleted'! !

!StripeObject methodsFor: 'deleting' stamp: 'PaulDeBruicker 10/25/2011 12:07'!
deleteUrl 
	^self class url , '/' , self id! !

!StripeObject methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/24/2011 21:07'!
from: aResponse using: anApiKey
	apiKey := anApiKey.
	id:=aResponse at: 'id' ifAbsent:[].
	self refreshFrom: aResponse with: anApiKey.! !

!StripeObject methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/24/2011 15:10'!
hasAnId
	^true! !

!StripeObject methodsFor: 'accessing' stamp: 'PaulDeBruicker 10/24/2011 20:10'!
id
	
	^ id ifNil:[id:=values at: 'id']! !

!StripeObject methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/24/2011 15:55'!
ignoredAttributes
	| i |
	i := Set new.
	i add: #api_key.
	i add: #id.
	i add: #object.
	^ i! !

!StripeObject methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/24/2011 15:25'!
initialize
	values:=Dictionary new.
	unsavedValues:=Set new.
	transientValues:=Set new. 
! !

!StripeObject methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/24/2011 16:08'!
keys
	^values keys! !

!StripeObject methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/24/2011 15:54'!
permanentAttributes
	| p |
	p := Set new.
	p add: #api_key.
	^ p! !

!StripeObject methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/24/2011 15:42'!
refreshFrom: aResponse with: anApiKey
	^self refreshFrom: aResponse with: anApiKey partially: false! !

!StripeObject methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 14:48'!
refreshFrom: aResponse with: anApiKey partially: aBoolean
	|removedKeys addedKeys|
		aResponse
		at: 'error'
		ifPresent: [:v |StripeError signal: ((aResponse at: 'error') at:'message')]
		ifAbsent: [ 
	apiKey := anApiKey.
	removedKeys:=aBoolean ifTrue: [Set new] ifFalse:[Set newFrom:(values keys difference: aResponse keys)].
	addedKeys :=Set newFrom:(aResponse keys difference: values keys).
	unsavedValues:= Set newFrom: aResponse keys.
	removedKeys do:[:each | values removeKey: each.
						transientValues add: each.
						unsavedValues remove: each.].
	unsavedValues copy do:[:each | values at: each put: (StripeSystem convert: (aResponse at: each) toStripeObjectUsing: anApiKey).
		transientValues remove: each ifAbsent: [].
		unsavedValues remove: each ifAbsent:[]]].
	! !

!StripeObject methodsFor: 'retrieving' stamp: 'PaulDeBruicker 10/25/2011 11:16'!
retrievalUrl 
	^self class url , '/' , self id! !

!StripeObject methodsFor: 'retrieving' stamp: 'PaulDeBruicker 10/25/2011 12:49'!
retrieveFromStripe
	|response client parsed |
	client:= (ZnNeoClient new) logToTranscript.
	client username: self class secretApiKey password:''.
	response:=(client url: self  retrievalUrl; get) .
	parsed:=JSJsonParser parse: response asString readStream. 
	parsed at:'error' ifPresent:[:v| StripeError new signal:((parsed at:'error') at:'message')]ifAbsent:[
	^StripeSystem convert: parsed toStripeObjectUsing: self class secretApiKey]! !

!StripeObject methodsFor: 'deleting' stamp: 'PaulDeBruicker 10/25/2011 14:16'!
updateUrl 
	^self class url , '/' , self id! !

!StripeObject methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 14:49'!
updateWith: optionalDictionary

	|response client parsed |
	client:= (ZnNeoClient new) logToTranscript.
	client username: self class secretApiKey password:''.
	client formAddAll:  optionalDictionary.
	response:=(client url: self  updateUrl; post) .
	parsed:=JSJsonParser parse: response asString readStream. 
	self refreshFrom: parsed with: self class secretApiKey partially: true ! !

!StripeObject methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/24/2011 18:31'!
url
	^self class url ,'/', id greaseString encodeForHTTP  ! !

!StripeObject methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 09:04'!
values
	^values! !

StripeObject subclass: #StripePlan
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe'!

!StripePlan class methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 12:56'!
newFrom: aDictionary
"see https://stripe.com/docs/api?lang=curl#create_plan 

you can't create more than one of the same plan, so we check to see if the one you want to make exists and if not create it"
|existingPlan | 
	existingPlan:=self retrieveWithId: (aDictionary at: 'id').
	^existingPlan isNil ifTrue:[self new createWith: aDictionary] ifFalse:[existingPlan]! !

!StripePlan class methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 12:55'!
retrieveWithId: anId
	| response client parsed |
	client := ZnNeoClient new logToTranscript.
	client username: self secretApiKey password: ''.
	client url: self url , '/' , anId.
	response := client get.
	parsed := JSJsonParser parse: response asString readStream.
	parsed
		at: 'error'
		ifPresent: [ :v | ^nil ]
		ifAbsent: [ ^ StripeSystem convert: parsed toStripeObjectUsing: self secretApiKey ]! !

!StripePlan methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/24/2011 17:57'!
object
	^'plan'! !

StripeObject subclass: #StripeSubscription
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe'!

!StripeSubscription methodsFor: 'accessing' stamp: 'PaulDeBruicker 10/25/2011 13:55'!
plan
	^values at: 'plan'! !

!StripeSubscription methodsFor: 'accessing' stamp: 'PaulDeBruicker 10/25/2011 15:13'!
status
	^values at:'status'! !

!StripeSubscription methodsFor: 'accessing' stamp: 'PaulDeBruicker 10/25/2011 13:57'!
trial_end
	^values at:'trial_end'! !

StripeObject subclass: #StripeToken
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe'!

!StripeToken class methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 14:55'!
newFrom: aCard for: anAmount
	^self new charge: anAmount to: aCard! !

!StripeToken methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 14:55'!
charge: anAmount to: aCard 
	|dict charge|
	dict:=Dictionary new.
	dict at: 'amount' put: anAmount. "amount must be in pennies e.g. 99 equals $0.99"
	dict at: 'currency' put: 'usd'. "they only support USD right now`"
	dict at: 'card[number]' put: aCard number.
	dict at: 'card[cvc]' put: aCard cvc.
	dict at: 'card[exp_month]' put: aCard exp_month.
	dict at: 'card[exp_year]' put: aCard exp_year.
	aCard address_line1 notNil ifTrue:[
	dict at: 'card[address_line1]' put: aCard address_line1].
	aCard address_zip notNil ifTrue:[
	dict at: 'card[address_zip]' put: aCard address_zip].
	
	self createWith: dict.! !

Object subclass: #StripeSystem
	instanceVariableNames: 'root'
	classVariableNames: 'StripeObjectDictionary'
	poolDictionaries: ''
	category: 'Stripe'!

StripeSystem class
	instanceVariableNames: 'default'!

StripeSystem class
	instanceVariableNames: 'default'!

!StripeSystem class methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 13:46'!
convert: aResponse toStripeObjectUsing: anAPIKey


			^ aResponse isDictionary
				ifTrue: [ (StripeObjectDictionary at: (aResponse at: 'object' ifAbsent:['object'])) newFrom: aResponse using: anAPIKey ]
				ifFalse: [ 
					aResponse isCollection
						ifTrue: [ aResponse collect: [ :each | self convert: each toStripeObjectUsing: anAPIKey ] ]
						ifFalse: [ aResponse ] ] ! !

!StripeSystem class methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/24/2011 17:59'!
default
	^ default ifNil: [ default := StripeSystem new ]! !

!StripeSystem class methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/24/2011 21:00'!
initialize
"
StripeSystem initialize
"
	self initializeStripeObjectDictionary.

	! !

!StripeSystem class methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 14:51'!
initializeStripeObjectDictionary

	StripeObjectDictionary:=Dictionary new.
	StripeObjectDictionary at: 'charge' put: StripeCharge.
	StripeObjectDictionary at: 'customer' put: StripeCustomer.
	StripeObjectDictionary at: 'invoicetiem' put: StripeInvoiceItem.
	StripeObjectDictionary at: 'invoice' put: StripeInvoice.
	StripeObjectDictionary at: 'plan' put: StripePlan.
	StripeObjectDictionary at: 'coupon' put: StripeCoupon.
	StripeObjectDictionary at: 'card' put: StripeCard.	
	StripeObjectDictionary at: 'discount' put: StripeDiscount.	
	StripeObjectDictionary at: 'subscription' put: StripeSubscription.	
	StripeObjectDictionary at: 'token' put: StripeToken.	
		
	StripeObjectDictionary at: 'object' put: StripeObject.	! !

!StripeSystem class methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/24/2011 18:00'!
instancesOf: aClass
	^ self default instancesOf: aClass! !

!StripeSystem class methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/25/2011 09:06'!
objectsToIds: aCollectionOrObject
	| returnValue |
	 aCollectionOrObject isDictionary
		ifTrue: [ 
			returnValue := Dictionary new.
			aCollectionOrObject keysAndValuesDo: [ :key :val | returnValue at: key put: (self objectsToIds: val) ] ]
		ifFalse: [ 
			returnValue:=(aCollectionOrObject isCollection and:[aCollectionOrObject isString not ])
				ifTrue: [ aCollectionOrObject collect: [ :each | self objectsToIds: each ] ]
				ifFalse: [ aCollectionOrObject ] ].
			
		^returnValue! !

!StripeSystem class methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/24/2011 15:16'!
symbolizeNames: anObject
	| returnValue |
	anObject isDictionary
		ifTrue: [ 
			returnValue := Dictionary new.
			anObject keysAndValuesDo: [ :key :val | returnValue at: key asSymbol put: (self symbolizeNames: val) ] ]
		ifFalse: [ 
			anObject isCollection
				ifTrue: [ returnValue := anObject collect: [ :each | self symbolizeNames: each ] ]
				ifFalse: [ returnValue := anObject ] ].
	^ returnValue! !

!StripeSystem methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/24/2011 17:58'!
at: aString
	^ self root at: aString ifAbsentPut: [ OrderedCollection new ]! !

!StripeSystem methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/24/2011 17:58'!
instancesOf: aClass
	^ self at: aClass name! !

!StripeSystem methodsFor: 'as yet unclassified' stamp: 'PaulDeBruicker 10/24/2011 17:59'!
root
	^ root ifNil: [ root := IdentityDictionary new ]! !

Error subclass: #StripeError
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe'!

StripeError subclass: #APIConnectionError
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe'!

StripeError subclass: #APIError
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe'!

StripeError subclass: #AuthenticationError
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe'!

StripeError subclass: #CardError
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe'!

StripeError subclass: #InvalidRequestError
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Stripe'!
StripeSystem initialize!
StripeCreditCardForm initialize!
